@@ -14,7 +14,8 @@
 #' @name berryFunctions-package
 #' @aliases berryFunctions-package berryFunctions
 #' @docType package
-#' @note Get the most recent code updates at \url{https://github.com/brry}\cr
+#' @note dataDWD and readDWD have moved to the package rdwd: \url{https://github.com/brry/rdwd#rdwd}\cr\cr 
+#' Get the most recent code updates at \url{https://github.com/brry}\cr
 #' At some places you'll find \code{## not run} in the examples. These code
 #' blocks were excluded from checking while building, mainly because they are
 #' interactive and need mouseclicks, or because they open another device/file.
@@ -22,11 +23,7 @@
 #' do find non-executable code, please tell me!\cr
 #' Feel free to suggest packages in which these functions would fit well.\cr
 #' I strongly depend on - and therefore welcome - any feedback!\cr\cr
-#' The following functions have been deprecated:\cr
-#' changeAttribute, showAttribute, shapeZoom: moved to \url{https://github.com/brry/shapeInteractive}\cr
-#' extremeStat, extremeStatLmom: moved to distLextreme in \url{https://github.com/brry/extremeStat}\cr
-#' compFiles has been renamed to \code{\link{compareFiles}}. combineTextfiles has been renamed to \code{\link{combineFiles}}.
-#' @author Berry Boessenkool, \email{berry-b@@gmx.de}, 2011-2016
+#' @author Berry Boessenkool, \email{berry-b@@gmx.de}, 2011-2017
 #' @keywords package documentation
 #' @examples
 #' 
@@ -34,14 +31,3 @@
 #' 
 NULL
 
-
-#' dataDWD and readDWD are now in 'rdwd'.
-#' 
-#' \code{dataDWD} and \code{readDWD} have been greatly improved and are now in the package \code{rdwd}.
-#' This provides a much better infrastructure for file selection and downloading.
-#' See \url{https://github.com/brry/rdwd#rdwd} for usage instructions.
-#' 
-#' @name dataDWD
-#' @aliases dataDWD readDWD
-#' 
-NULL
